@@ -3,6 +3,7 @@ Functionality for formatting vulnerability results using the CycloneDX SBOM form
 """
 
 import enum
+import logging
 from typing import Dict, List, cast
 
 from cyclonedx import output
@@ -11,10 +12,13 @@ from cyclonedx.model.component import Component
 from cyclonedx.model.vulnerability import Vulnerability
 from cyclonedx.parser import BaseParser
 
+import pip_audit._fix as fix
 import pip_audit._service as service
 
 from .interface import VulnerabilityFormat
 
+logger = logging.getLogger(__name__)
+
 
 class _PipAuditResultParser(BaseParser):
     def __init__(self, result: Dict[service.Dependency, List[service.VulnerabilityResult]]):
@@ -33,8 +37,7 @@ class _PipAuditResultParser(BaseParser):
                     Vulnerability(
                         id=vuln.id,
                         description=vuln.description,
-                        advisories=[f"Upgrade: {v}" for v in vuln.fix_versions],
-                        recommendations=["Upgrade"],
+                        recommendation="Upgrade",
                     )
                 )
 
@@ -65,16 +68,34 @@ class CycloneDxFormat(VulnerabilityFormat):
 
         self._inner_format = inner_format
 
-    def format(self, result: Dict[service.Dependency, List[service.VulnerabilityResult]]) -> str:
+    @property
+    def is_manifest(self):
+        """
+        See `VulnerabilityFormat.is_manifest`.
+        """
+        return True
+
+    def format(
+        self,
+        result: Dict[service.Dependency, List[service.VulnerabilityResult]],
+        fixes: List[fix.FixVersion],
+    ) -> str:
         """
         Returns a CycloneDX formatted string for a given mapping of dependencies to vulnerability
         results.
 
         See `VulnerabilityFormat.format`.
         """
+        if fixes:
+            logger.warning("--fix output is unsupported by CycloneDX formats")
+
         parser = _PipAuditResultParser(result)
         bom = Bom.from_parser(parser)
 
-        formatter = output.get_instance(bom=bom, output_format=self._inner_format.value)
+        formatter = output.get_instance(
+            bom=bom,
+            output_format=self._inner_format.value,
+            schema_version=output.SchemaVersion.V1_4,
+        )
 
         return formatter.output_as_string()
