@@ -5,6 +5,7 @@ import pytest
 import requests
 from packaging.requirements import Requirement
 from packaging.version import Version
+from pip_api import Requirement as ParsedRequirement
 from requests.exceptions import HTTPError
 from resolvelib.resolvers import InconsistentCandidate, ResolutionImpossible
 
@@ -47,6 +48,7 @@ def check_deps(resolved_deps: List[ResolvedDependency], expected_deps: List[Reso
         assert found
 
 
+@pytest.mark.online
 def test_resolvelib():
     resolver = resolvelib.ResolveLibResolver()
     req = Requirement("flask==2.0.1")
@@ -66,6 +68,7 @@ def test_resolvelib():
     check_deps(resolved_deps[req], expected_deps)  # type: ignore
 
 
+@pytest.mark.online
 def test_resolvelib_extras():
     resolver = resolvelib.ResolveLibResolver()
 
@@ -97,6 +100,7 @@ def test_resolvelib_extras():
     check_deps(resolved_deps[req], expected_deps)  # type: ignore
 
 
+@pytest.mark.online
 def test_resolvelib_sdist():
     resolver = resolvelib.ResolveLibResolver()
     req = Requirement("ansible-core==2.11.5")
@@ -295,7 +299,114 @@ def test_resolvelib_http_notfound(monkeypatch):
     resolved_deps = dict(resolver.resolve_all(iter([req])))
     assert len(resolved_deps) == 1
     expected_deps = [
-        SkippedDependency(name="flask", skip_reason='Could not find project "flask" on PyPI')
+        SkippedDependency(
+            name="flask",
+            skip_reason='Could not find project "flask" on any of the supplied index URLs: '
+            "['https://pypi.org/simple']",
+        )
     ]
     assert req in resolved_deps
     assert resolved_deps[req] == expected_deps
+
+
+def test_resolvelib_multiple_indexes(monkeypatch):
+    url1 = "https://index1"
+    url2 = "https://index2"
+    package_url1 = f"{url1}/flask"
+    package_url2 = f"{url2}/flask"
+    data1 = (
+        '<a href="https://files.pythonhosted.org/packages/d4/6a/'
+        "93500f2a7089b4e993fb095215979890b6204a5ba3f6b0f63dc6c3c6c827/Flask-0.5.tar.gz#"
+        'sha256=20e176b1db0e2bfe92d869f7b5d0ee3e5d6cb60e793755aaf2284bd78a6202ea">Flask-0.5.tar.gz'
+        "</a><br/>"
+    )
+    data2 = (
+        '<a href="https://files.pythonhosted.org/packages/44/86/'
+        "481371798994529e105633a50b2332638105a1e191053bc0f4bbc9b91791/Flask-0.6.tar.gz#"
+        'sha256=9dc18a7c673bf0a6fada51e011fc411285a8301f6dfc1c000ebfa272b5e609e4">Flask-0.6.tar.gz'
+        "</a><br/>"
+    )
+
+    monkeypatch.setattr(
+        pypi_provider.Candidate, "_get_metadata_for_sdist", lambda _: get_metadata_mock()
+    )
+
+    def get_multiple_index_package_mock(url):
+        if url == package_url1:
+            return get_package_mock(data1)
+        else:
+            assert url == package_url2
+            return get_package_mock(data2)
+
+    resolver = resolvelib.ResolveLibResolver([url1, url2])
+    monkeypatch.setattr(
+        resolver.provider.session, "get", lambda url, **kwargs: get_multiple_index_package_mock(url)
+    )
+
+    # We want to check that dependency resolution is considering packages found on both indexes
+    #
+    # Test with a requirement that will resolve to a package on the first index
+    req = Requirement("flask<=0.5")
+    resolved_deps = dict(resolver.resolve_all(iter([req])))
+    assert req in resolved_deps
+    assert resolved_deps[req] == [ResolvedDependency("flask", Version("0.5"))]
+
+    # Now test with a requirement that will resolve to a package on the second index
+    req = Requirement("flask<=0.6")
+    resolved_deps = dict(resolver.resolve_all(iter([req])))
+    assert req in resolved_deps
+    assert resolved_deps[req] == [ResolvedDependency("flask", Version("0.6"))]
+
+
+def test_resolvelib_package_missing_on_one_index(monkeypatch):
+    url1 = "https://index1"
+    url2 = "https://index2"
+    package_url1 = f"{url1}/flask"
+    package_url2 = f"{url2}/flask"
+    data1 = (
+        '<a href="https://files.pythonhosted.org/packages/d4/6a/'
+        "93500f2a7089b4e993fb095215979890b6204a5ba3f6b0f63dc6c3c6c827/Flask-0.5.tar.gz#"
+        'sha256=20e176b1db0e2bfe92d869f7b5d0ee3e5d6cb60e793755aaf2284bd78a6202ea">Flask-0.5.tar.gz'
+        "</a><br/>"
+    )
+
+    monkeypatch.setattr(
+        pypi_provider.Candidate, "_get_metadata_for_sdist", lambda _: get_metadata_mock()
+    )
+
+    # Simulate the package not existing on the second index
+    def get_multiple_index_package_mock(url):
+        if url == package_url1:
+            return get_package_mock(data1)
+        else:
+            assert url == package_url2
+            pkg = get_package_mock(str())
+            pkg.status_code = 404
+            return pkg
+
+    resolver = resolvelib.ResolveLibResolver([url1, url2])
+    monkeypatch.setattr(
+        resolver.provider.session, "get", lambda url, **kwargs: get_multiple_index_package_mock(url)
+    )
+
+    # If a package doesn't exist on one index, we shouldn't expect an error. We should just skip it
+    # and only use the other index for finding candidates.
+    req = Requirement("flask<=0.5")
+    resolved_deps = dict(resolver.resolve_all(iter([req])))
+    assert req in resolved_deps
+    assert resolved_deps[req] == [ResolvedDependency("flask", Version("0.5"))]
+
+    # Now test with a requirement that will resolve to a package on the second index
+    req = Requirement("flask<=0.6")
+    resolved_deps = dict(resolver.resolve_all(iter([req])))
+    assert req in resolved_deps
+    assert resolved_deps[req] == [ResolvedDependency("flask", Version("0.5"))]
+
+
+def test_resolvelib_skip_editable():
+    resolver = resolvelib.ResolveLibResolver(skip_editable=True)
+    req = ParsedRequirement("foo==1.0.0", editable=True, filename="stub", lineno=1)
+
+    deps = resolver.resolve(req)  # type: ignore
+    assert len(deps) == 1
+    assert deps[0] == SkippedDependency(name="foo", skip_reason="requirement marked as editable")
